# Slot: local_names


map from local identifier to slot

URI: [http://w3id.org/biolink/biolinkml/meta/local_names](slot_uri)
## Domain and Range

[Definition](Definition.md) -><sub>opt</sub> [[String](String.md)]
## Inheritance

## Children

## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
